@charset "UTF-8";
@import url("https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.3/font/bootstrap-icons.css");
body {
  background-color: #f5f5f5;
  font-family: sans-serif;
  font-size: 10px;
  margin: 0;
  border: 0;
}

.accordion {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 15px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  transition: 0.4s;
}
.accordion.active, .accordion:hover {
  background-color: #ccc;
}
.accordion:after {
  content: "+";
  color: #777;
  font-weight: bold;
  float: right;
  bottom: 50px;
}
.accordion.active:after {
  content: "−";
}
.accordion span {
  font-weight: bold;
  font-size: 15px;
}

.panel {
  padding: 0 18px;
  background-color: white;
  max-height: 0;
  overflow: hidden;
  transition: max-height 0.2s ease-out;
  margin-bottom: 10px;
  font-size: 15px;
}
.panel .testSummary {
  display: flex;
  border: 1px solid #ccc;
  margin: 10px 0;
  justify-content: center;
  align-items: center;
  padding: 10px 0;
  font-style: italic;
}

.panel .exception {
  display: flex;
  border: 1px solid #ccc;
  margin: 10px 0;
  justify-content: flex-start;
  align-items: flex-start;
  padding: 10px 10px;
  background-color: indianred;
  color: #f6bc00;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
  width: 100%;
  border: 1px solid #ddd;
  margin-bottom: 10px;
}
table th,
table td {
  text-align: center;
  padding: 5px;
  height: 5px;
}
table th#t-col-w-1,
table td#t-col-w-1 {
  width: 8%;
}
table th#t-col-w-2,
table td#t-col-w-2 {
  width: 25%;
}
table .wrap {
  width: 25%;
  word-wrap: break-word;
}
table td a i {
  font-size: 30px;
}
table tr:nth-child(even) {
  background-color: #f2f2f2;
}
table .bi-check-circle {
  color: green;
  font-size: 18px;
}
table .bi-x-circle {
  color: red;
  font-size: 18px;
}
table .bi-bug-fill {
  color: red;
  font-size: 18px;
}

.clear {
  clear: both;
  height: 90px;
}

footer {
  background-color: #263238;
  position: fixed;
  left: 0;
  bottom: 0;
  width: 100%;
  color: white;
  text-align: center;
}
footer p a {
  font-size: 15px;
  color: #0d6efd;
  text-decoration: none;
}
footer p a:hover {
  text-decoration: underline;
  color: #f6bc00;
}
footer h3 {
  font-family: "Segoe UI", Tahoma, Geneva, Verdana, sans-serif;
  font-size: 25px;
  color: #f6bc00;
  margin: 10px 0;
}
footer .copyright {
  text-align: center;
  color: #ccc;
  font-size: 12px;
  margin: 0 0 10px 0;
}

header {
  background-color: #263238;
  left: 0;
  bottom: 0;
  width: 100%;
  color: #ccc;
  text-align: center;
  padding: 10px 0;
  border-radius: 0 0 50% 200%/100%;
  margin-bottom: 10px;
}
header h1 {
  font-family: sans-serif;
  font-weight: 10;
}

.modal-content .modal-header button span {
  font-size: 25px;
}
.modal-content .modal-body img {
  margin: 0 auto;
}/*# sourceMappingURL=style.css.map */